@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2019 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_OS_MACOSX_H
-#define SQUID_OS_MACOSX_H
+#ifndef SQUID_COMPAT_OS_MACOSX_H
+#define SQUID_COMPAT_OS_MACOSX_H
 
 #if _SQUID_APPLE_
 
@@ -29,5 +29,5 @@
 #include "compat/cmsg.h"
 
 #endif /* _SQUID_APPLE_ */
-#endif /* SQUID_OS_MACOSX_H */
+#endif /* SQUID_COMPAT_OS_MACOSX_H */
 
