@@ -1,16 +1,16 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_NTLMAUTH_H
-#define SQUID_NTLMAUTH_H
+#ifndef SQUID_LIB_NTLMAUTH_NTLMAUTH_H
+#define SQUID_LIB_NTLMAUTH_NTLMAUTH_H
 
 /* NP: All of this cruft is little endian */
-/* Endian functions are usualy handled by the OS but not always. */
+/* Endian functions are usually handled by the OS but not always. */
 #include "ntlmauth/support_endian.h"
 
 #ifdef __cplusplus
@@ -192,5 +192,5 @@ int ntlm_unpack_auth(const ntlm_authenticate *auth,
 }
 #endif
 
-#endif /* SQUID_NTLMAUTH_H */
+#endif /* SQUID_LIB_NTLMAUTH_NTLMAUTH_H */
 
