@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_DELAYBUCKET_H
-#define SQUID_DELAYBUCKET_H
+#ifndef SQUID_SRC_DELAYBUCKET_H
+#define SQUID_SRC_DELAYBUCKET_H
 
 class DelaySpec;
 class StoreEntry;
@@ -35,5 +35,5 @@ private:
     int level_;
 };
 
-#endif /* SQUID_DELAYBUCKET_H */
+#endif /* SQUID_SRC_DELAYBUCKET_H */
 
