@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2019 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_READREQUEST_H
-#define SQUID_READREQUEST_H
+#ifndef SQUID_SRC_DISKIO_READREQUEST_H
+#define SQUID_SRC_DISKIO_READREQUEST_H
 
 #include "base/RefCount.h"
 #include "cbdata.h"
@@ -19,12 +19,12 @@ class ReadRequest : public RefCountable
 public:
     typedef RefCount<ReadRequest> Pointer;
     ReadRequest(char *buf, off_t offset, size_t len);
-    virtual ~ReadRequest() {}
+    ~ReadRequest() override {}
 
     char *buf;
     off_t offset;
     size_t len;
 };
 
-#endif /* SQUID_READREQUEST_H */
+#endif /* SQUID_SRC_DISKIO_READREQUEST_H */
 
