@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLSERVERNAME_H
-#define SQUID_ACLSERVERNAME_H
+#ifndef SQUID_SRC_ACL_SERVERNAME_H
+#define SQUID_SRC_ACL_SERVERNAME_H
 
 #include "acl/Acl.h"
 #include "acl/DomainData.h"
@@ -17,8 +17,7 @@ class ACLServerNameData : public ACLDomainData {
     MEMPROXY_CLASS(ACLServerNameData);
 public:
     ACLServerNameData() : ACLDomainData() {}
-    virtual bool match(const char *);
-    virtual ACLData<char const *> *clone() const;
+    bool match(const char *) override;
 };
 
 class ACLServerNameStrategy : public ACLStrategy<char const *>
@@ -26,10 +25,10 @@ class ACLServerNameStrategy : public ACLStrategy<char const *>
 
 public:
     /* ACLStrategy API */
-    virtual int match (ACLData<MatchType> * &, ACLFilledChecklist *);
-    virtual bool requiresRequest() const {return true;}
-    virtual const Acl::Options &options();
-    virtual bool valid() const;
+    int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
+    bool requiresRequest() const override {return true;}
+    const Acl::Options &options() override;
+    bool valid() const override;
 
 private:
     Acl::BooleanOptionValue useClientRequested; ///< Ignore server-supplied names
@@ -37,5 +36,5 @@ private:
     Acl::BooleanOptionValue useConsensus; ///< Ignore mismatching names
 };
 
-#endif /* SQUID_ACLSERVERNAME_H */
+#endif /* SQUID_SRC_ACL_SERVERNAME_H */
 
