@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_AUTH_DIGEST_SCHEME_H
-#define SQUID_AUTH_DIGEST_SCHEME_H
+#ifndef SQUID_SRC_AUTH_DIGEST_SCHEME_H
+#define SQUID_SRC_AUTH_DIGEST_SCHEME_H
 
 #if HAVE_AUTH_MODULE_DIGEST
 
@@ -18,7 +18,6 @@ namespace Auth
 namespace Digest
 {
 
-/// \ingroup AuthSchemeAPI
 /// \ingroup AuthAPI
 class Scheme : public Auth::Scheme
 {
@@ -26,12 +25,12 @@ class Scheme : public Auth::Scheme
 public:
     static Auth::Scheme::Pointer GetInstance();
     Scheme() {};
-    virtual ~Scheme() {}
+    ~Scheme() override {}
 
     /* per scheme */
-    virtual char const *type () const;
-    virtual void shutdownCleanup();
-    virtual Auth::Config *createConfig();
+    char const *type () const override;
+    void shutdownCleanup() override;
+    Auth::SchemeConfig *createConfig() override;
 
     /* Not implemented */
     Scheme(Scheme const &);
@@ -46,5 +45,5 @@ private:
 } // namespace Auth
 
 #endif /* HAVE_AUTH_MODULE_DIGEST */
-#endif /* SQUID_AUTH_DIGEST_SCHEME_H */
+#endif /* SQUID_SRC_AUTH_DIGEST_SCHEME_H */
 
