@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_AUTH_DIGEST_USER_H
-#define _SQUID_AUTH_DIGEST_USER_H
+#ifndef SQUID_SRC_AUTH_DIGEST_USER_H
+#define SQUID_SRC_AUTH_DIGEST_USER_H
 
 #if HAVE_AUTH_MODULE_DIGEST
 
@@ -26,14 +26,14 @@ class User : public Auth::User
     MEMPROXY_CLASS(Auth::Digest::User);
 
 public:
-    User(Auth::Config *, const char *requestRealm);
-    virtual ~User();
+    User(Auth::SchemeConfig *, const char *requestRealm);
+    ~User() override;
     int authenticated() const;
-    virtual int32_t ttl() const override;
+    int32_t ttl() const override;
 
     /* Auth::User API */
     static CbcPointer<Auth::CredentialsCache> Cache();
-    virtual void addToNameCache() override;
+    void addToNameCache() override;
 
     HASH HA1;
     int HA1created;
@@ -48,5 +48,5 @@ public:
 } // namespace Auth
 
 #endif /* HAVE_AUTH_MODULE_DIGEST */
-#endif /* _SQUID_AUTH_DIGEST_USER_H */
+#endif /* SQUID_SRC_AUTH_DIGEST_USER_H */
 
