@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2021 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_CHARSET_H
-#define _SQUID_CHARSET_H
+#ifndef SQUID_SRC_AUTH_TOUTF_H
+#define SQUID_SRC_AUTH_TOUTF_H
 
 #include "sbuf/forward.h"
 
@@ -20,5 +20,5 @@ SBuf Cp1251ToUtf8(const char *in);
 /// returns whether the given input is a valid (or empty) sequence of UTF-8 code points
 bool isValidUtf8String(const char *source, const char *sourceEnd);
 
-#endif /* _SQUID_CHARSET_H */
+#endif /* SQUID_SRC_AUTH_TOUTF_H */
 
