@@ -8,8 +8,8 @@
 
 /* DEBUG: section 86    ESI processing */
 
-#ifndef SQUID_ESIINCLUDE_H
-#define SQUID_ESIINCLUDE_H
+#ifndef SQUID_SRC_ESI_INCLUDE_H
+#define SQUID_SRC_ESI_INCLUDE_H
 
 #include "esi/Context.h"
 #include "esi/Element.h"
@@ -47,9 +47,9 @@ public:
     void subRequestDone (ESIStreamContext::Pointer, bool);
 
     struct {
-        int onerrorcontinue:1; /* on error return zero data */
-        int failed:1; /* Failed to process completely */
-        int finished:1; /* Finished getting subrequest data */
+        unsigned int onerrorcontinue:1; /* on error return zero data */
+        unsigned int failed:1; /* Failed to process completely */
+        unsigned int finished:1; /* Finished getting subrequest data */
     } flags;
     ESIStreamContext::Pointer src;
     ESIStreamContext::Pointer alt;
@@ -71,5 +71,5 @@ private:
     void prepareRequestHeaders(HttpHeader &tempheaders, ESIVarState *vars);
 };
 
-#endif /* SQUID_ESIINCLUDE_H */
+#endif /* SQUID_SRC_ESI_INCLUDE_H */
 
