@@ -1,16 +1,16 @@
 /*
- * Copyright (C) 1996-2019 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_HELPER_REQUEST_H
-#define _SQUID_SRC_HELPER_REQUEST_H
+#ifndef SQUID_SRC_HELPER_REQUEST_H
+#define SQUID_SRC_HELPER_REQUEST_H
 
 #include "helper/forward.h"
-#include "SquidTime.h"
+#include "time/gadgets.h"
 
 namespace Helper
 {
@@ -21,10 +21,10 @@ class Request
 
 public:
     Request(HLPCB *c, void *d, const char *b) :
-        buf(b ? xstrdup(b) : NULL),
+        buf(b ? xstrdup(b) : nullptr),
         callback(c),
         data(cbdataReference(d)),
-        placeholder(b == NULL),
+        placeholder(b == nullptr),
         Id(0),
         retries(0)
     {
@@ -55,5 +55,5 @@ public:
 
 } // namespace Helper
 
-#endif /* _SQUID_SRC_HELPER_REQUEST_H */
+#endif /* SQUID_SRC_HELPER_REQUEST_H */
 
