@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2019 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_IDENT_ACLIDENT_H
-#define SQUID_IDENT_ACLIDENT_H
+#ifndef SQUID_SRC_IDENT_ACLIDENT_H
+#define SQUID_SRC_IDENT_ACLIDENT_H
 
 #if USE_IDENT
 
@@ -19,7 +19,7 @@ class IdentLookup : public ACLChecklist::AsyncState
 
 public:
     static IdentLookup *Instance();
-    virtual void checkForAsync(ACLChecklist *)const;
+    void checkForAsync(ACLChecklist *)const override;
 
 private:
     static IdentLookup instance_;
@@ -36,25 +36,24 @@ class ACLIdent : public ACL
 
 public:
     ACLIdent(ACLData<char const *> *newData, char const *);
-    ACLIdent (ACLIdent const &old);
-    ACLIdent & operator= (ACLIdent const &rhs);
-    ~ACLIdent();
+    ~ACLIdent() override;
 
     /* ACL API */
-    virtual char const *typeString() const;
-    virtual void parse();
-    virtual bool isProxyAuth() const {return true;}
-    virtual void parseFlags();
-    virtual int match(ACLChecklist *checklist);
-    virtual SBufList dump() const;
-    virtual bool empty () const;
-    virtual ACL *clone()const;
+    char const *typeString() const override;
+    void parse() override;
+    bool isProxyAuth() const override {return true;}
+    int match(ACLChecklist *checklist) override;
+    SBufList dump() const override;
+    bool empty () const override;
 
 private:
+    /* ACL API */
+    const Acl::Options &lineOptions() override;
+
     ACLData<char const *> *data;
     char const *type_;
 };
 
 #endif /* USE_IDENT */
-#endif /* SQUID_IDENT_ACLIDENT_H */
+#endif /* SQUID_SRC_IDENT_ACLIDENT_H */
 
