@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2019 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_TYPEDEFS_H
-#define SQUID_TYPEDEFS_H
+#ifndef SQUID_SRC_TYPEDEFS_H
+#define SQUID_SRC_TYPEDEFS_H
 
 #include "anyp/ProtocolType.h"
 #include "enums.h"
@@ -21,5 +21,5 @@ typedef void DWCB(int, int, size_t, void *);    /* disk write CB */
 class CachePeer;
 typedef void IRCB(CachePeer *, peer_t, AnyP::ProtocolType, void *, void *data);
 
-#endif /* SQUID_TYPEDEFS_H */
+#endif /* SQUID_SRC_TYPEDEFS_H */
 
